{% load extras %}{{ all_id }}
<BR>
<table id="object_table" class="table table-striped table-bordered table-hover">
	<thead>
		<tr>
			{% for field in field_names %}
				<th>{{ field }}</th>
			{% endfor %}
		</tr>
	</thead>
	<tfoot>
		<tr>
			{% for field in field_names %}
				<th>{{ field }}</th>
			{% endfor %}
		</tr>
	</tfoot>
	<tbody>
		{% for object in objects %}
			<tr>
				{% for field in result_fields %}
					<td>
						{{ object|getta:field|safe }}
					</td>
				{% endfor %}
			</tr>
		{% endfor %}
	</tbody>
</table>