{% extends "base.html" %}
{% load extras %}

{% block scriptsready %}
	$('#generalobjs_table').DataTable();
	{% if all_id %}
		$('#ge_object').val('{{ obj_name }}');
		$('#ge_ids').val('{{ all_id }}');
	{% endif %}
{% endblock %}

{% block content %}
<!--<div class="container-fluid">
	<div class="container-fluid col-sm-4">
		<div class="well well-sm">
			<div class="btn-group" role="group" aria-label="">
				<button type="button" class="btn btn-default">-</button>
			</div>
		</div>
		<div class="panel panel-default">
			<div class="panel-body">
				<form class="form-horizontal">
				<div class="form-group">
					<label class="col-sm-4 control-label">Add</label>
					<div class="col-sm-8">
						<p class="form-control-static"><A href="{{ url_new }}">New</A></p>
					</div>
				</div>
				</form>
			</div>
		</div>
	</div>

	<div class="col-sm-8">
		<ul class="nav nav-tabs" role="tablist">
			<li role="presentation" class="active"><a href="#first_tab" data-toggle="tab">First</a></li>
		</ul>
		<div class="tab-content">
			<div role="tabpanel" class="tab-pane active" id="first_tab">
				<div role="panel" class="panel panel-default" id="first_panel">-->
					{% if additional_template %}
						{% include additional_template %}
					{% endif %}
					&nbsp;<BR>
					<div><h4>{{ class_name }}s</h4></div>
					<button type="button" class="btn btn-default" onClick="window.location = '{{ url_new }}'">New</button>
					<BR>&nbsp;
					{% if show_unused_download_excelsheet_button %}
						<button type="button" class="btn btn-default" data-toggle="modal" data-target="#excelModal" id="download_excelsheet"{% if all_id %}{% else %} style="display: none;"{% endif %}>Download Excel</button>
					{% endif %}
					<table id="generalobjs_table" class="table table-striped table-bordered table-hover">
						<thead>
							<tr>
								{% for field_name in field_names %}
									<th>{{ field_name }}</th>
								{% endfor %}
							</tr>
						</thead>
						<tfoot>
							<tr>
								{% for field_name in field_names %}
									<th>{{ field_name }}</th>
								{% endfor %}
							</tr>
						</tfoot>
						{% for field in fields %}
							<tr>
								{% for value in field %}
									<td{% if value.bgcolor %} bgcolor={{ value.bgcolor }}{% endif %}>
										{% if value.is_bold %}<B>{% endif %}
										{% if value.color %}<font color="{{ value.color }}">{% endif %}
											{{ value|safe }}
										{% if value.color %}</font>{% endif %}
										{% if value.is_bold %}</B>{% endif %}
									</td>
								{% endfor %}
							</tr>
						{% endfor %}
					</table>
					{% include "blocks/download_excelsheet_modal.html" %}
<!--				</div>
			</div>
		</div>
	</div>
</div>-->
	
	
{% endblock %}
