# Generated by Django 2.2.15 on 2021-01-17 18:59

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='GOStatus',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=128)),
                ('code', models.CharField(max_length=128)),
                ('parent_obj_description', models.CharField(max_length=128)),
                ('next_statuses', models.CharField(blank=True, max_length=256, null=True)),
                ('is_entrant', models.BooleanField(default=False)),
                ('is_leaving', models.BooleanField(default=False)),
            ],
        ),
    ]
