# Generated by Django 2.2.15 on 2021-01-18 23:19

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('generalobj', '0002_auto_20210117_2150'),
    ]

    operations = [
        migrations.AddField(
            model_name='gostatus',
            name='is_backward',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='gostatus',
            name='is_forward',
            field=models.BooleanField(default=True),
        ),
    ]
