# Generated by Django 2.2.15 on 2021-01-17 21:50

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('generalobj', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='gostatus',
            name='next_statuses',
            field=models.CharField(blank=True, default='', max_length=256, null=True),
        ),
    ]
