

<div class="modal fade" id="excelModal" tabindex="-1" role="dialog" aria-labelledby="excelModalLabel" data-backdrop=true>
    <div class="modal-dialog" role="document">
        <div class="modal-content">
            <div class="modal-header">
                <button type="button" class="close" data-dismiss="modal" aria-label="Close"><span aria-hidden="true">&times;</span></button>
                <h4 class="modal-title" id="excelModalLabel">Download Excel</h4>
            </div>
            <form method='post' name='excel_form' action="{% url 'download_excelsheet' %}">
                <div class="modal-body">
                    {% csrf_token %}
                    <div class="form-group hidden">
                        <input class="hidden" name="ge_object" id="ge_object">
                    </div>
                    <div class="form-group hidden">
                        <input class="hidden" name="ge_ids" id="ge_ids">
                    </div>
                    <div class="form-group hidden">
                        <input class="hidden" name="ge_type" id="ge_type">
                    </div>
                    <div class="form-group">
                        <label for="ge_filename" class="control-label">File name:</label>
                        <input type="text" class="form-control" name="ge_filename" id="ge_filename" value="download.xlsx">
                    </div>
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn btn-default" data-dismiss="modal">Close</button>
                    <button type="submit" class="btn btn-primary">Save</button>
                </div>
            </form>
        </div>
    </div>
</div>

